/*$DELIMITER:/*/
CREATE TABLE JCR_CONTAINER(
  VERSION VARCHAR(255) NOT NULL PRIMARY KEY
  )
/
CREATE TABLE JCR_SITEM(
    ID VARCHAR2(255) NOT NULL PRIMARY KEY,
    VERSION INTEGER NOT NULL,
    CONTAINER_NAME VARCHAR2(255) NOT NULL,
    PATH VARCHAR2(4000) NOT NULL
    )
/
CREATE INDEX JCR_IDX_SITEM_ID ON JCR_SITEM(ID, CONTAINER_NAME)
/
CREATE INDEX JCR_IDX_SITEM_PATH ON JCR_SITEM(PATH, CONTAINER_NAME)
/
CREATE INDEX JCR_IDX_SITEM_CONTAINER_NAME ON JCR_SITEM(CONTAINER_NAME)
/
CREATE TABLE JCR_SNODE(
    ID VARCHAR2(255) NOT NULL PRIMARY KEY,
    ORDER_NUM INTEGER,
    PARENT_ID VARCHAR2(255),
    CONSTRAINT JCR_FK_SNODE_PARENT FOREIGN KEY(PARENT_ID) REFERENCES JCR_SNODE(ID),
    CONSTRAINT JCR_FK_SNODE_ITEM FOREIGN KEY(ID) REFERENCES JCR_SITEM(ID)
    )
/
CREATE INDEX JCR_IDX_SNODE_PARENT ON JCR_SNODE(ID, PARENT_ID, ORDER_NUM)
/
CREATE TABLE JCR_SPROPERTY(
    ID VARCHAR2(255) NOT NULL PRIMARY KEY,
    TYPE INTEGER NOT NULL,
    PARENT_ID VARCHAR2(255) NOT NULL,
    MULTIVALUED INTEGER NOT NULL,
    CONSTRAINT JCR_FK_SPROPERTY_NODE FOREIGN KEY(PARENT_ID) REFERENCES JCR_SNODE(ID),
    CONSTRAINT JCR_FK_SPROPERTY_ITEM FOREIGN KEY(ID) REFERENCES JCR_SITEM(ID)
    )
/
CREATE INDEX JCR_IDX_SPROPERTY_PARENT ON JCR_SPROPERTY(ID, PARENT_ID)
/
CREATE INDEX JCR_IDX_SPROPERTY_TYPE ON JCR_SPROPERTY(ID, TYPE)
/
CREATE TABLE JCR_SVALUE(
    ID INTEGER PRIMARY KEY,
    DATA BLOB,
    ORDER_NUM INTEGER,
    PROPERTY_ID VARCHAR2(255) NOT NULL,
    CONSTRAINT JCR_FK_VALUE_PROPERTY FOREIGN KEY(PROPERTY_ID) REFERENCES JCR_SPROPERTY(ID)
)
/
CREATE INDEX JCR_IDX_SVALUE_PROPERTY ON JCR_SVALUE(PROPERTY_ID, ORDER_NUM)
/
CREATE sequence JCR_SVALUE_SEQ
/
CREATE OR REPLACE trigger BI_JCR_SVALUE
  before insert on JCR_SVALUE
  for each row
begin
  SELECT JCR_SVALUE_SEQ.nextval INTO :NEW.ID FROM dual;
end;
/
ALTER TRIGGER BI_JCR_SVALUE ENABLE
/
CREATE TABLE JCR_SREF(
  NODE_ID VARCHAR(255) NOT NULL,
  PROPERTY_ID VARCHAR(255) NOT NULL,
  ORDER_NUM INTEGER NOT NULL,
  CONSTRAINT JCR_PK_SREF PRIMARY KEY(NODE_ID, PROPERTY_ID, ORDER_NUM)
)
/
CREATE UNIQUE INDEX JCR_IDX_SREF_PROPERTY ON JCR_SREF(PROPERTY_ID, ORDER_NUM)
/